summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/meanwhile/meanwhilesession.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/meanwhile/meanwhilesession.cpp')
-rw-r--r--kopete/protocols/meanwhile/meanwhilesession.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kopete/protocols/meanwhile/meanwhilesession.cpp b/kopete/protocols/meanwhile/meanwhilesession.cpp
index c7121875..5f367540 100644
--- a/kopete/protocols/meanwhile/meanwhilesession.cpp
+++ b/kopete/protocols/meanwhile/meanwhilesession.cpp
@@ -426,7 +426,7 @@ void MeanwhileSession::syncContactsToServer()
if (contactgroup->type() == Kopete::Group::TopLevel) {
stgroup = topstgroup;
} else {
/* find (or create) a matching sametime list group */
stgroup = mwSametimeList_findGroup(list,
contactgroup->displayName().ascii());
if (stgroup == 0L) {
@@ -473,7 +473,7 @@ void MeanwhileSession::slotSocketDataAvailable()
{
HERE;
guchar *buf;
- Q_LONG bytesRead;
+ TQ_LONG bytesRead;
if (socket == 0L)
return;
@@ -548,17 +548,17 @@ void MeanwhileSession::resolveContactNickname(MeanwhileContact *contact)
TQString MeanwhileSession::getNickName(struct mwLoginInfo *logininfo)
{
if (logininfo == 0L || logininfo->user_name == 0L)
- return TQString::null;
+ return TQString();
return getNickName(logininfo->user_name);
}
TQString MeanwhileSession::getNickName(TQString name)
{
- int index = name.find(" - ");
+ int index = name.tqfind(" - ");
if (index != -1)
name = name.remove(0, index + 3);
- index = name.find('/');
+ index = name.tqfind('/');
if (index != -1)
name = name.left(index);
@@ -426,7 +426,7 @@ void MeanwhileSession::syncContactsToServer()
stgroup = topstgroup;
} else {
- /* find (or create) a matching sametime list group */
+ /* tqfind (or create) a matching sametime list group */
stgroup = mwSametimeList_findGroup(list,
contactgroup->displayName().ascii());